Learn R Programming

sc2sc (version 0.0.1-18)

cp2sc: Implements the geometric spatial transfer of statistics from Spanish postal code areas to census sections

Description

Transfers the statistics available in a set of Spanish postal codes to the corresponding spatial set of Spanish official census sections into force in a given year.

Usage

cp2sc(x, year, data.type = "counts", all.units = FALSE, na.rm = TRUE, ...)

Value

A list with the following components

df

A data frame with the statistics spatially transferred to the census sections corresponding to the year.sscc.dest division.

missing

A vector with the codes of the postal code areas included in x that are not available in the shp file of postal code area division.

Arguments

x

A data frame of order N x K (with K > 1) with the statistics to be spatially transferred/imputed. The first column must contains the codes of the postal code areas to which the statistics belong to. The statistical nature of the data columns must be of the same type. See the argument data.type.

year

An integer number. Reference year of the census sections to which the statistics are going to be transferred. Only 2001 and 2003 to 2025 are allowed.

data.type

A character string indicating the type of data to be transferred, either "counts" (aggregate statistics) or "averages" (mean, proportion or rate statistics). Default "counts".

all.units

A TRUE/FALSE value indicating the census section units of the destination division to be included in the output data frame. If TRUE all the units of the destination division are included. If FALSE only those units for which a value is imputed are included. Default, FALSE.

na.rm

A TRUE/FALSE logical value indicating whether NA values should be stripped before the computations proceed. Default, TRUE.

...

Other arguments to be passed to the function. Not currently used.

Author

Jose M. Pavia, pavia@uv.es

Virgilio Perez virgilio.perez@uv.es

References

Goerlich, FJ (2022). Elaboracion de un mapa de codigos postales de Espana con recursos libres. Como evitar pagar a Correos 6000 euros por informacion de referencia. Working Papers Ivie n. 2022-3. Valencia: Ivie. tools:::Rd_expr_doi("10.12842/WPIVIE_0322")

Pavia, JM and Cantarino, I (2017a). Can dasymetric mapping significantly improve population data reallocation in a dense urban area? Geographical Analysis, 49(2), 155-174. tools:::Rd_expr_doi("10.1111/gean.12112")

Pavia, JM and Cantarino, I (2017b). Dasymetric distribution of votes in a dense city. Applied Geography, 86, 22-31. tools:::Rd_expr_doi("10.1016/j.apgeog.2017.06.021")

Perez, V and Pavia, JM (2024a). Improving Accuracy in Geospatial Information Transfer: A Population Density-Based Approach, in 6th International Conference on Advanced Research Methods and Analytics (CARMA 2024), Editorial Universitat Politecnica de Valencia, pp. 326-333. tools:::Rd_expr_doi("10.4995/CARMA2024.2024.17796")

Perez, V and Pavia, JM (2024b) Automating the transfer of data between census sections and postal codes areas over time. An application to Spain. Investigaciones Regionales - Journal of Regional Research, forthcoming. tools:::Rd_expr_doi("10.38191/iirr-jorr.24.057")

See Also

sc2cp sc2sc

Examples

Run this code
data <- structure(list(CCPP = c(1120L, 1160L, 1250L, 1212L, 1213L),
                       income = c(15000L, 12000L, 11500L,
                       13000L, 12500L)),
                  class = "data.frame", row.names = c(NA, -5L))
example <- cp2sc(x = data, year = 2014, data.type = "averages")

Run the code above in your browser using DataLab